@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-from mootdx.consts import HQ_HOSTS, EX_HOSTS, GP_HOSTS
+from mootdx.consts import EX_HOSTS, GP_HOSTS, HQ_HOSTS
 
-__version__ = "0.6.10"
+__version__ = "0.6.11"
 __author__ = "bopo.wang<ibopo@126.com>"
 
 CONFIG = {
