@@ -58,13 +58,14 @@ HQ_HOSTS = [
 
 EX_HOSTS = [
     ('扩展市场深圳双线1', '112.74.214.43', 7727),
-    # ('扩展市场深圳双线2', '120.24.0.77', 7727),
+    ('扩展市场深圳双线2', '120.24.0.77', 7727),
     ('扩展市场深圳双线3', '47.107.75.159', 7727),
     ('扩展市场武汉主站1', '119.97.185.5', 7727),
-    # ('扩展市场武汉主站2', '202.103.36.71', 7727),
+    ('扩展市场武汉主站2', '202.103.36.71', 7727),
     ('扩展市场武汉主站3', '59.175.238.38', 7727),
     ('扩展市场北京双线', '47.92.127.181', 7727),
     ('扩展市场上海双线', '106.14.95.149', 7727),
+    ('扩展市场新加双线', '119.23.127.172', 7727),
 ]
 
 GP_HOSTS = [('默认财务数据线路', '120.76.152.87', 7709)]
