@@ -8,8 +8,7 @@ import pandas as pd
 from mootdx.logger import log
 
 headers = {
-    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) '
-                  'Chrome/90.0.4430.212 Safari/537.36',
+    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/90.0.4430.212 Safari/537.36',
     'Referer': 'http://stockpage.10jqka.com.cn/',
     'DNT': '1',
 }
@@ -24,8 +23,6 @@ def get_adjust_year(symbol=None, year='2021', factor='00'):
         factor = '01'
     elif factor == 'after':
         factor = '02'
-    else:
-        factor = factor
 
     if factor not in ['01', '02']:
         return pd.DataFrame(data=[None])
